@@ -11,7 +11,8 @@ def extract_libraries(sasobjsp_user: str,
                       metadata_port: str,
                       metadata_user: str,
                       metadata_password: str,
-                      metadata_repo,
+                      metadata_repo: str,
+                      java: str,
                       sas_session: AbstractSAS = None) -> list:
 
     get_all_libs_query = extract_lib_template.substitute(metadata_server=metadata_server,
@@ -24,7 +25,8 @@ def extract_libraries(sasobjsp_user: str,
                                   sasobjsp_host=sasobjsp_host,
                                   sasobjsp_user=sasobjsp_user,
                                   sasobjsp_pass=sasobjsp_pass,
-                                  appserver=appserver)
+                                  appserver=appserver,
+                                  java=java)
     sas_session.submit(get_all_libs_query)
     df = sas_session.read_dataset(libname='WORK', tablename='Libraries_final')
     return df.to_json(orient='records')
